@@ -1,22 +1,25 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2018 by Dominique Dumont.
+# This software is Copyright (c) 2008-2022 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-[
+use strict;
+use warnings;
+
+return [
   {
     'accept' => [
       '.*',
       {
         'type' => 'leaf',
-        'value_type' => 'uniline'
+        'value_type' => 'uniline',
+        'warn' => 'Unexpected systemd parameter. Please contact cme author to update systemd model.'
       }
     ],
-    'class_description' => 'common install section',
     'element' => [
       'Alias',
       {
@@ -40,8 +43,8 @@ aliasing.',
         },
         'description' => 'This option may be used more than once, or a
 space-separated list of unit names may be given. A symbolic
-link is created in the .wants/ or
-.requires/ directory of each of the
+link is created in the C<.wants/> or
+C<.requires/> directory of each of the
 listed units when this unit is installed by systemctl
 enable. This has the effect that a dependency of
 type C<Wants> or C<Requires>
@@ -52,19 +55,55 @@ C<Wants> and C<Requires> in
 the [Unit] section for details.
 
 WantedBy=foo.service in a service
-bar.service is mostly equivalent to
+C<bar.service> is mostly equivalent to
 Alias=foo.service.wants/bar.service in the
 same file. In case of template units, systemctl
 enable must be called with an instance name, and
 this instance will be added to the
-.wants/ or
-.requires/ list of the listed unit. E.g.
+C<.wants/> or
+C<.requires/> list of the listed unit. E.g.
 WantedBy=getty.target in a service
-getty@.service will result in
+C<getty@.service> will result in
 systemctl enable getty@tty2.service
 creating a
-getty.target.wants/getty@tty2.service
-link to getty@.service.
+C<getty.target.wants/getty@tty2.service>
+link to C<getty@.service>.
+',
+        'type' => 'list'
+      },
+      'RequiredBy',
+      {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'This option may be used more than once, or a
+space-separated list of unit names may be given. A symbolic
+link is created in the C<.wants/> or
+C<.requires/> directory of each of the
+listed units when this unit is installed by systemctl
+enable. This has the effect that a dependency of
+type C<Wants> or C<Requires>
+is added from the listed unit to the current unit. The primary
+result is that the current unit will be started when the
+listed unit is started. See the description of
+C<Wants> and C<Requires> in
+the [Unit] section for details.
+
+WantedBy=foo.service in a service
+C<bar.service> is mostly equivalent to
+Alias=foo.service.wants/bar.service in the
+same file. In case of template units, systemctl
+enable must be called with an instance name, and
+this instance will be added to the
+C<.wants/> or
+C<.requires/> list of the listed unit. E.g.
+WantedBy=getty.target in a service
+C<getty@.service> will result in
+systemctl enable getty@tty2.service
+creating a
+C<getty.target.wants/getty@tty2.service>
+link to C<getty@.service>.
 ',
         'type' => 'list'
       },
@@ -95,44 +134,9 @@ no effect in non-template unit files. The specified string
 must be usable as instance identifier.',
         'type' => 'leaf',
         'value_type' => 'uniline'
-      },
-      'RequiredBy',
-      {
-        'cargo' => {
-          'type' => 'leaf',
-          'value_type' => 'uniline'
-        },
-        'description' => 'This option may be used more than once, or a
-space-separated list of unit names may be given. A symbolic
-link is created in the .wants/ or
-.requires/ directory of each of the
-listed units when this unit is installed by systemctl
-enable. This has the effect that a dependency of
-type C<Wants> or C<Requires>
-is added from the listed unit to the current unit. The primary
-result is that the current unit will be started when the
-listed unit is started. See the description of
-C<Wants> and C<Requires> in
-the [Unit] section for details.
-
-WantedBy=foo.service in a service
-bar.service is mostly equivalent to
-Alias=foo.service.wants/bar.service in the
-same file. In case of template units, systemctl
-enable must be called with an instance name, and
-this instance will be added to the
-.wants/ or
-.requires/ list of the listed unit. E.g.
-WantedBy=getty.target in a service
-getty@.service will result in
-systemctl enable getty@tty2.service
-creating a
-getty.target.wants/getty@tty2.service
-link to getty@.service.
-',
-        'type' => 'list'
       }
     ],
+    'generated_by' => 'parseman.pl from systemd doc',
     'name' => 'Systemd::Section::Install'
   }
 ]
